Forest Tools provides functions for analyzing remote sensing forest data. Functions like vwf and mcws are applied to rasterized canopy height models (CHM) to detect treetops and outline their respective crowns.
Once a CHM is segmented into discrete crowns, glcm can compute textural metrics for each crowns. This is usually done using orthorectified imagery, but can also characterize the CHM's texture.